/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
package org.greenstone.gatherer.shell;

/** Title:        The Gatherer<br>
 *  Description:  The Gatherer: a tool for gathering and enriching digital collections.<br>
 *  Copyright:    Copyright (c) 2001<br>
 *  Company:      The University of Waikato<br>
 *  Written:        /  /01<br>
 *  Revised:      12/05/02 - Commented<br>
 *                29/05/02 - Moved into correct package<br>
 *  @author John Thompson, Greenstone Digital Libraries
 *  @version 2.1 */

import java.awt.Component;
import java.util.ArrayList;
import javax.swing.JProgressBar;
import org.greenstone.gatherer.shell.GShellEvent;
import org.greenstone.gatherer.shell.GShellProgressMonitor;

/** This is the most basic implementation of <i>GShellProgressMonitor</i> in that it doesn't even attempt to parse the process messages. Instead it has one graphic which is displayed once the start() method is called, and another which appears after the stop().
 */
public class GBasicProgressMonitor 
    extends JProgressBar 
    implements GShellProgressMonitor {
    /** Whether the process has been asked to stop. */
    private boolean stop = false;
    /** Constructor **/
    public GBasicProgressMonitor() {
	super();
    }
    /** Don't do anything if we are given a progress bar, we have our own.
     * @param progress_bar A JProgressBar
     */
    public void addProgressBar(JProgressBar progress_bar) {
    }
    /** Determine the script exit value according to the progress monitor. This gets around a problem where several script failures actually result with a successful exit value.
     * @return A <i>int</i> with a value of zero if and only if the script was successful.
     */
    public int exitValue() {
	// Always return true as we don't know any better.
	return 0;
    }
    /** As we are probably accessing this via an interface we need to gain
     * access to the component itself.
     */
    public Component getProgress() {
	return this;
    }

    public JProgressBar getSharedProgress() {
	return null;
    }

    public void messageOnProgressBar(String message)
    {
	if ((message!=null) & (message!="")) {
	    setString(message);
	}
	else {
	    setString(null);
	}
    }


    /** Method to determine the state of the stop flag, which may be set by the visual component that created this monitor.
     * @return A <strong>boolean</strong> indicating if the process has been asked to stop.
     */
    public boolean hasSignalledStop() {
	return stop;
    }
    /** Inform the progress bar that it should programatically increment progress by one step. */
    public void increment() {
	// We can't do anything about this.
    }
    /** The parse method is how more complex progress bars figure out how far they have progressed. However we don't.
     * @param queue a queue which at the moment should contain a single GShellEvent
     */
    public void process(ArrayList queue) {
    }

    public void reset() {};

    public void saving() {
    }

    /** Since the creator of this process monitor is actually in the GUI, this class provides the simpliest way to send a cancel process message between the two.
     * @param state The desired state of the stop flag as a <strong>boolean</strong>.
     */
    public void setStop(boolean state) {
	stop = state;
    }
    /** This method tells this class that the job it is showing the progress
     * for has begun.
     */
    public void start() {
	setIndeterminate(true);
    }
    /** This method tells this class that the job it is showing the progress
     * for has come to an end.
     */
    public void stop() {
	setIndeterminate(false);
    }
}
